@@ -8,6 +8,4 @@ from pylsp.__main__ import LOG_FORMAT
 logging.basicConfig(level=logging.DEBUG, format=LOG_FORMAT)
 
 
-pytest_plugins = [
-    'test.fixtures'
-]
+pytest_plugins = ["test.fixtures"]
